NUIAuthLoginReq class
- Inheritance
-
- Object
- NUIEnt<
NUIAuthLoginReq> - NUIAuthLoginReq
Constructors
- NUIAuthLoginReq({required String username, required String password, String? refreshToken, required String grantType})
- NUIAuthLoginReq.empty()
Properties
- grantType ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- password ↔ String
-
getter/setter pair
- refreshToken ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- username ↔ String
-
getter/setter pair
Methods
-
fromJson(
Map< String, dynamic> json) → NUIAuthLoginReq -
inherited
-
mapper(
) → NUIEntMapper< NUIAuthLoginReq> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toMap(
) → Map< String, dynamic> -
inherited
-
toMapQuery(
{Map< NUIEntType, EntCustomerMapper> ? customMapper}) → Map<String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited